Learn R Programming

richCluster (version 1.0.2)

merge_enrichment_results: Merge List of Enrichment Results

Description

This function merges multiple enrichment results ('enrichment_results') into a single dataframe by combining unique GeneID elements across each geneset, and averaging Pvalue / Padj values for each term across all enrichment_results.

Usage

merge_enrichment_results(enrichment_results)

Value

A single merged geneset dataframe with all original columns suffixed with the index of the geneset, with new columns 'GeneID', 'Pvalue', 'Padj' containing the merged values.

Arguments

enrichment_results

A list of geneset dataframes containing columns c('Term', 'GeneID', 'Pvalue', 'Padj')