This function merges multiple enrichment results ('enrichment_results') into a single dataframe by combining unique GeneID elements across each geneset, and averaging Pvalue / Padj values for each term across all enrichment_results.
merge_enrichment_results(enrichment_results)A single merged geneset dataframe with all original columns suffixed with the index of the geneset, with new columns 'GeneID', 'Pvalue', 'Padj' containing the merged values.
A list of geneset dataframes containing columns c('Term', 'GeneID', 'Pvalue', 'Padj')